@@ -155,12 +155,13 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *http
 	char *hex_cmd=NULL, *hex_session=NULL, *hex_data=NULL, *hex_path=NULL, *hex_host=NULL;
 	char *host=NULL, *port_str=NULL, *hostport;
 	char *http_auth=NULL;
-	char *http_realhost=NULL;
+	char http_realhost[1024], *http_realport_tmp;
 	char buf[8192], *retbuf=NULL;
 	int fd;
 	int sink=0;
 	int datalen_val;
 	int http_authlen=0;
+	int http_realport=http_port;
 	unsigned int datalen_loc;
 
 	PRINTERR("Entering tcpcgi_getdata()");
@@ -183,6 +184,10 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *http
 		if (!port_str) {
 			PRINTERR("Unable to parse destination.");
 			if (status) *status=-1;
+			if (hex_cmd) free(hex_cmd);
+			if (hex_session) free(hex_session);
+			if (hex_data) free(hex_data);
+			if (hex_path) free(hex_path);
 			return(NULL);
 		}
 		*port_str=0;
@@ -192,21 +197,44 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *http
 	}
 
 	if (proxyhost) {
-		http_realhost=proxyhost;
+		/* This will cause a slow, steady memory leak ... */
+		strcpy(http_realhost, proxyhost);
+		http_realport_tmp=strchr(http_realhost, ':');
+		if (http_realport_tmp) {
+			*http_realport_tmp='\0';
+			http_realport=atoi(http_realport_tmp+1);
+		} else {
+			http_realport=http_port;
+		}
 	} else {
-		http_realhost=http_host;
+		strcpy(http_realhost, http_host);
+		http_realport=http_port;
 	}
-	fd=createconnection_tcp(http_realhost, http_port);
+	PRINTERR("Creating connection to \"%s\" on port %i", http_realhost, http_realport);
+
+	fd=createconnection_tcp(http_realhost, http_realport);
+
 	if (fd<0) {
 		PERROR("connect");
 		PRINTERR("Couldn't connect!");
 		if (status) *status=-1;
+		if (hex_cmd) free(hex_cmd);
+		if (hex_session) free(hex_session);
+		if (hex_data) free(hex_data);
+		if (hex_host) free(hex_host);
+		if (hex_path) free(hex_path);
 		return(NULL);
 	}
 	fp=fdopen(fd, "r+");
 	if (!fp) {
 		PERROR("fdopen");
 		if (status) *status=-1;
+		if (http_auth[0]!='\0') free(http_auth);
+		if (hex_cmd) free(hex_cmd);
+		if (hex_session) free(hex_session);
+		if (hex_data) free(hex_data);
+		if (hex_host) free(hex_host);
+		if (hex_path) free(hex_path);
 		return(NULL);
 	}
 
@@ -223,10 +251,10 @@ void *tcpcgi_getdata(char *http_host, int http_port, char *http_path, char *http
 
 	buf[sizeof(buf)-1]='\0';
 	if (use_post) {
-		fprintf(fp, "POST %s HTTP/1.0\r\nHost: %s\r\n%sContent-length: %i\r\n\r\n%s\r\n", hex_path, http_host, http_auth, (int) strlen(buf), buf);
+		fprintf(fp, "POST %s HTTP/1.0\r\nHost: %s:%i\r\n%sContent-length: %i\r\n\r\n%s\r\n", hex_path, http_host, http_port, http_auth, (int) strlen(buf), buf);
 		PRINTERR("POST http://%s:%i%s?[%i]%s HTTP/1.0\n", http_host, http_port, hex_path, (int) strlen(buf), buf);
 	} else {
-		fprintf(fp, "GET %s?%s HTTP/1.0\r\nHost: %s\r\n%s\r\n", hex_path, buf, http_host, http_auth);
+		fprintf(fp, "GET %s:%i?%s HTTP/1.0\r\nHost: %s:%i\r\n%s\r\n", hex_path, http_port, buf, http_host, http_port, http_auth);
 		PRINTERR("GET http://%s:%i%s?[%i]%s HTTP/1.0\n", http_host, http_port, hex_path, (int) strlen(buf), buf);
 	}
 	fflush(fp);
