@@ -60,15 +60,16 @@ struct sessioninfo {
 };
 
 int tcpcgi_errmsg(int fd, char *msg) {
-	PRINTERR("[fd=%i]: ERROR: %s", fd, msg);
-	write(fd, "ERROR: ", strlen("ERROR: "));
+	PRINTERR("[fd=%i]: FAIL: %s", fd, msg);
+	write(fd, "FAIL - ", strlen("FAIL - "));
 	write(fd, msg, strlen(msg));
 	write(fd, "\n", 1);
 	return(-1);
 }
 
 int tcpcgi_write(int fd, char *msg) {
-	PRINTERR("[fd=%i]: MSG: %s", fd, msg);
+	PRINTERR("[fd=%i]: SUCCESS: %s", fd, msg);
+	write(fd, "SUCCESS: ", strlen("SUCCESS: "));
 	write(fd, msg, strlen(msg));
 	write(fd, "\n", 1);
 	return(0);
@@ -114,25 +115,21 @@ void tcpcgi_free_session(void *data, void *key) {
 /* Create a session and connect to a host. */
 int tcpcgi_cmd_open(int fd, cache_t *parms) {
 	struct sessioninfo *si;
-	char *host, *hostport, *port_str;
+	char *host, *port_str;
 	char *session;
 	int port;
 	int sockfd;
 
 	PRINTERR("Starting tcpcgi_cmd_open");
-	hostport=cache_find(parms, "dest", strlen("dest"), NULL);
-	session=cache_find(parms, "session", strlen("session"), NULL);
-	if (!hostport) return(tcpcgi_errmsg(fd, "Need parameter: dest"));
-	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: session"));
+	host=cache_find(parms, "host", strlen("host"), NULL);
+	port_str=cache_find(parms, "port", strlen("port"), NULL);
+	session=cache_find(parms, "id", strlen("id"), NULL);
+	if (!host) return(tcpcgi_errmsg(fd, "Need parameter: host"));
+	if (!port_str) return(tcpcgi_errmsg(fd, "Need parameter: port"));
+	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: id"));
 	si=cache_find(sess, session, strlen(session), NULL);
-	if (si) return(tcpcgi_errmsg(fd, "Improper parameter: session;  Session exists"));
+	if (si) return(tcpcgi_errmsg(fd, "Improper parameter: id;  Session exists"));
 
-	/* Parse the host:port value into two seperate variables */
-	port_str=strchr(hostport, ':');
-	if (!port_str) return(tcpcgi_errmsg(fd, "Improper parameter: dest"));
-	*port_str=0;
-	port_str++;
-	host=hostport;
 	port=atoi(port_str);
 
 	/* Connect to host:port */
@@ -163,11 +160,11 @@ int tcpcgi_cmd_close(int fd, cache_t *parms) {
 	char *session;
 
 	PRINTERR("Starting tcpcgi_cmd_close");
-	session=cache_find(parms, "session", strlen("session"), NULL);
-	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: session"));
+	session=cache_find(parms, "id", strlen("id"), NULL);
+	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: id"));
 
 	si=cache_find(sess, session, strlen(session), NULL);
-	if (!si) return(tcpcgi_errmsg(fd, "Improper parameter: session;  Session does not exists"));
+	if (!si) return(tcpcgi_errmsg(fd, "Improper parameter: id;  Session does not exists"));
 
 	/* Delete the session (note: this also closes the socket). */
 	cache_delete(sess, session, strlen(session), NULL, 1);
@@ -188,11 +185,11 @@ int tcpcgi_cmd_get(int fd, cache_t *parms) {
 	int sockflags, oldsockflags;
 
 	PRINTERR("Starting tcpcgi_cmd_get");
-	session=cache_find(parms, "session", strlen("session"), NULL);
-	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: session"));
+	session=cache_find(parms, "id", strlen("id"), NULL);
+	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: id"));
 
 	si=cache_find(sess, session, strlen(session), NULL);
-	if (!si) return(tcpcgi_errmsg(fd, "Improper parameter: session;  Session does not exists"));
+	if (!si) return(tcpcgi_errmsg(fd, "Improper parameter: id;  Session does not exists"));
 	sockfd=si->sockfd;
 
 	/* Put the socket into non-blocking mode. */
@@ -239,9 +236,9 @@ int tcpcgi_cmd_put(int fd, cache_t *parms) {
 
 	PRINTERR("Starting tcpcgi_cmd_put");
 	proto=cache_find(parms, "proto", strlen("proto"), NULL);
-	session=cache_find(parms, "session", strlen("session"), NULL);
+	session=cache_find(parms, "id", strlen("id"), NULL);
 	data=cache_find(parms, "data", strlen("data"), &datalen);
-	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: session"));
+	if (!session) return(tcpcgi_errmsg(fd, "Need parameter: id"));
 	if (!data) return(tcpcgi_errmsg(fd, "Need parameter: data"));
 	if (!proto) proto="tcp";
 	proto_type=SOCK_STREAM;
@@ -249,7 +246,7 @@ int tcpcgi_cmd_put(int fd, cache_t *parms) {
 
 	if (proto_type!=SOCK_DGRAM) {
 		si=cache_find(sess, session, strlen(session), NULL);
-		if (!si) return(tcpcgi_errmsg(fd, "Improper parameter: session;  Session does not exists"));
+		if (!si) return(tcpcgi_errmsg(fd, "Improper parameter: id;  Session does not exists"));
 		while ((x=write(si->sockfd, data, datalen))>0) {
 			datalen-=x;
 			if (datalen==0) break;
@@ -280,8 +277,8 @@ int tcpcgi_cmd_put(int fd, cache_t *parms) {
 
 void *tcpcgi_cmd_list[][2]={	{"open", tcpcgi_cmd_open},
 				{"close", tcpcgi_cmd_close},
-				{"put", tcpcgi_cmd_put},
-				{"get", tcpcgi_cmd_get},
+				{"write", tcpcgi_cmd_put},
+				{"read", tcpcgi_cmd_get},
                            };
 
 int tcpcgi_handledata(int fd, unsigned char *data, unsigned int datalen) {
@@ -339,7 +336,7 @@ int tcpcgi_handledata(int fd, unsigned char *data, unsigned int datalen) {
 	 * handle it, then call that function with 3 arguments:
 	 * fd, ci->parms, &sess
 	 */
-	cmd=cache_find(ci->parms, "cmd", strlen("cmd"), &cmd_len);
+	cmd=cache_find(ci->parms, "action", strlen("action"), &cmd_len);
 	for (i=0; i<(sizeof(tcpcgi_cmd_list)/sizeof(void *))/2; i++) {
 		if (memcmp(cmd, tcpcgi_cmd_list[i][0], cmd_len)==0) {
 			func=tcpcgi_cmd_list[i][1];
